@@ -424,9 +424,13 @@ else:
         print("Batch-2")
     import os
     path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.txt"
-    with open(path,'w') as f:  
+    py="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.py"
+    with open(path,'w+') as f:
         f.write(s)
     f.close()
+    with open(py,'w+') as f1:
+        f1.write(s)
+    f1.close()
 '''
     try:
         m=sys.argv[1]
